Example class

Annotations
  • @JsonSerializable.new()

Constructors

Example({required String title, String? documentation, Map<String, Object?> input = const {}, Map<String, Object?> output = const {}, ErrorExample? error})
const
Example.fromJson(Map<String, Object?> json)
factory

Properties

documentation → String?
final
error → ErrorExample?
final
hashCode → int
The hash code for this object.
no setterinherited
input → Map<String, Object?>
final
output → Map<String, Object?>
final
props → List<Object?>
The type's equatable properties.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Serializes this as a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited