HttpApiKeyAuthTrait class

Implemented types
Annotations

Constructors

HttpApiKeyAuthTrait({String? scheme, required String name, required Location location})
const
HttpApiKeyAuthTrait.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSynthetic → bool
Checks if this trait is persisted with the shape, or if it is a synthetic, or transient trait, only meant to temporarily aid in some kind of in-memory model transformation.
no setteroverride
location → Location
final
name → String
final
props → List<Object?>
The type's equatable properties.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String?
final
shapeId → ShapeId
Returns the fully-qualified shape ID of the trait.
no setteroverride
value → HttpApiKeyAuthTrait
The value of the trait.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Serializes this as a JSON object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

id → const ShapeId