HttpMalformedRequestDefinition class

Defines a request to be used by an HttpMalformedRequest test case.

Annotations
  • @JsonSerializable.new()

Constructors

HttpMalformedRequestDefinition({String? body, Map<String, String> headers = const {}, String? host, required String method, List<String> queryParams = const [], String? uri})
const
HttpMalformedRequestDefinition.fromJson(Map<String, Object?> json)
factory

Properties

body → String?
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
final
host → String?
final
method → String
final
props → List<Object?>
The type's equatable properties.
no setter
queryParams → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Serializes this as a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited