PathMatcher class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

PathMatcher({required String path, required String expected, required PathComparator comparator})
const
PathMatcher.fromJson(Map<String, Object?> json)
factory

Properties

comparator → PathComparator
final
expected → String
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited