ServiceTrait class

Registers a service as an AWS service. This trait is required for all AWS services modeled in Smithy.

Implemented types
Implementers
Annotations

Constructors

ServiceTrait({required String sdkId, String? cloudFormationName, String? arnNamespace, String? cloudTrailEventSource, String? endpointPrefix})
const
ServiceTrait.fromJson(Object? json)
factory

Properties

arnNamespace → String?
The AWS ARN service namespace of the service.
final
cloudFormationName → String?
The AWS CloudFormation service name.
final
cloudTrailEventSource → String?
The CloudTrail event source name of the service.
final
endpointPrefix → String?
The endpoint prefix for the service.
final
hashCode → int
The hash code for this object.
no setterinherited
isSynthetic → bool
Checks if this trait is persisted with the shape, or if it is a synthetic, or transient trait, only meant to temporarily aid in some kind of in-memory model transformation.
no setteroverride
props → List<Object?>
The type's equatable properties.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkId → String
The SDK service ID.
final
shapeId → ShapeId
Returns the fully-qualified shape ID of the trait.
no setteroverride
value → ServiceTrait
The value of the trait.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(ShapeId target) → ResolvedServiceTrait
Resolves the service trait definition for the given target service shape.
toJson() → Map<String, Object?>
Serializes this as a JSON object.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

id → const ShapeId