ShapeType class

Inheritance
Available extensions

Properties

category → Category

Available on ShapeType, provided by the ShapeTypeX extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type

Available on ShapeType, provided by the ShapeTypeX extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ShapeType>
no setter
values → BuiltSet<ShapeType>
no setter

Static Methods

deserialize(String string) → ShapeType
valueOf(String name) → ShapeType

Constants

apply → const ShapeType
bigDecimal → const ShapeType
bigInteger → const ShapeType
blob → const ShapeType
boolean → const ShapeType
byte → const ShapeType
document → const ShapeType
double → const ShapeType
enum_ → const ShapeType
float → const ShapeType
integer → const ShapeType
intEnum → const ShapeType
list → const ShapeType
long → const ShapeType
map → const ShapeType
member → const ShapeType
operation → const ShapeType
resource → const ShapeType
service → const ShapeType
set → const ShapeType
short → const ShapeType
string → const ShapeType
structure → const ShapeType
timestamp → const ShapeType
union → const ShapeType