SmithyAst class abstract

Constructors

SmithyAst([void updates(SmithyAstBuilder)])
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata → BuiltMap<String, JsonObject>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapes → ShapeMap
no setter
version → SmithyVersion
no setter

Methods

merge(SmithyAst other) → SmithyAst
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SmithyAstBuilder)) → SmithyAst
Rebuilds the instance.
inherited
toBuilder() → SmithyAstBuilder
Converts the instance to a builder B.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SmithyAst>
no setter

Static Methods

fromJson(Map<String, Object?> json) → SmithyAst