SmithyPattern class

Implementers

Constructors

SmithyPattern(String pattern, List<Segment> segments, {bool allowsGreedyLabels = true})

Properties

greedyLabel → Segment?
Gets the greedy label of the pattern, if present.
no setter
hashCode → int
The hash code for this object.
no setterinherited
labels → Iterable<Segment>
All segments that are labels.
no setter
pattern → String
final
props → List<Object>
The type's equatable properties.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments → List<Segment>
final

Methods

getLabel(String name) → Segment?
Get a label by case-insensitive name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited