Waiter class

Annotations
  • @JsonSerializable.new()

Constructors

Waiter({String? documentation, required List<AcceptorDefinition> acceptors, int minDelay = Waiter.defaultMinDelay, int maxDelay = Waiter.defaultMaxDelay, List<String> tags = const []})
const
Waiter.fromJson(Object? json)
factory

Properties

acceptors → List<AcceptorDefinition>
final
documentation → String?
final
hashCode → int
The hash code for this object.
no setterinherited
maxDelay → int
final
minDelay → int
final
props → List<Object?>
The type's equatable properties.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
Serializes this as a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultMaxDelay → const int
defaultMinDelay → const int